bayespy.inference.vmp.nodes.stochastic.Distribution
===================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. autoclass:: Distribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Distribution.compute_mask_to_parent
      ~Distribution.compute_message_to_parent
      ~Distribution.plates_from_parent
      ~Distribution.plates_to_parent
      ~Distribution.random
   
   

   
   
   